@@ -681,16 +681,18 @@ class DADSignal(DADSignalInfo):
         """
         return [list(line) for line in self.as_iterable_data_table()]
 
-    def write_signal_to_csv(self, filename: str):
+    def write_signal_to_csv(self, filename: str) -> str:
         """
         Writes the signal intensities to the specified csv file.
 
         :param filename: file name to write to
+        :return: file path that was written
         """
         with open(filename, 'wt') as f:
             for line in self.as_iterable_data_table():
                 f.write(",".join([str(val) for val in line]))
                 f.write('\n')
+        return filename
 
 
 class HPLCSample(HPLCSampleInfo):
@@ -772,7 +774,7 @@ class HPLCSample(HPLCSampleInfo):
         self.signals.append(new_signal)
         return new_signal
 
-    def write_signals_to_csv(self, directory: str = None):
+    def write_signals_to_csv(self, directory: Union[str, pathlib.Path] = None) -> List[str]:
         """
         Writes the signals to csv in the directory specified. If no directory is specified, the csv files will be
         written to the directory path specified in the directory attribute of the instance.
@@ -783,15 +785,18 @@ class HPLCSample(HPLCSampleInfo):
             if self.directory is None:
                 raise ValueError('No directory was specified and the instance does not have a directory attribute.')
             directory = self.directory
+        directory = pathlib.Path(directory)
+        written_paths = []
         for signal in self.signals:
+            file_name = directory / f'{signal}.csv'
             signal.write_signal_to_csv(
-                os.path.join(
-                    directory,
-                    f'{signal}.csv'
-                )
+                file_name
             )
+            written_paths.append(str(file_name))
         # write TAC
-        with open(os.path.join(directory, 'Total Absorbance Chromatogram.csv'), 'wt') as f:
+        tac_file_name = directory / 'Total Absorbance Chromatogram.csv'
+        written_paths.append(str(tac_file_name))
+        with open(tac_file_name, 'wt') as f:
             f.write(
                 f'Retention Time (min),'  
                 f'Total Absorbance Chromatogram ({self.spectrum.chromatogram.yunits}),\n'
@@ -801,13 +806,14 @@ class HPLCSample(HPLCSampleInfo):
                     self.spectrum.total_absorbance_chromatogram
             ):
                 f.write(f'{rt},{intensity},\n')
+        return written_paths
 
-    def write_signals_to_xlsx(self, output_file: str = None):
+    def write_signals_to_xlsx(self, output_file: str = None) -> str:
         """
         Writes the signals to a single excel file.
 
         :param output_file: target file. If this is not specified
-        :return:
+        :return: path to the written file
         """
         if output_file is None:
             output_file = os.path.join(
@@ -866,3 +872,4 @@ class HPLCSample(HPLCSampleInfo):
             excel.remove(excel['Sheet'])
 
         excel.save(output_file)
+        return output_file
